@@ -6,7 +6,7 @@ from python_framework.api.src.helper import Serializer
 from python_framework.api.src.service.openapi.OpenApiKey import Key as k
 from python_framework.api.src.service.openapi.OpenApiValue import Value as v
 from python_framework.api.src.service.openapi import OpenApiDocumentationFile
-from python_framework.api.src.service.openapi.OpenApiDocumentationFile import DOCUMENTATION_FILE, KW_OPEN_API, KW_RESOURCE, KW_UI
+from python_framework.api.src.service.openapi.OpenApiDocumentationFile import KW_OPEN_API, KW_RESOURCE, KW_UI
 
 COLON_DOUBLE_BAR = '://'
 LOCAL_HOST = 'localhost'
@@ -32,6 +32,7 @@ ABLE_TO_RECIEVE_BODY_LIST = [
 ]
 
 DEFAULT_CONTENT_TYPE = 'application/json'
+JSON_OBJECT_NAME = 'json'
 
 KW_API = 'api'
 KW_INFO = 'info'
@@ -60,7 +61,7 @@ def addSwagger(apiInstance, appInstance):
     documentationUrl = f'{apiInstance.baseUrl}{c.SLASH}{KW_OPEN_API}'
     swaggerUi = get_swaggerui_blueprint(
         documentationUrl,
-        DOCUMENTATION_FILE
+        OpenApiDocumentationFile.getDocumentationFileName(apiInstance)
     )
     pythonFrameworkStaticFiles = f'{globals.OS_SEPARATOR}python_framework{globals.OS_SEPARATOR}api{globals.OS_SEPARATOR}resource'
     swaggerStaticFiles = f'{globals.OS_SEPARATOR}{KW_OPEN_API}{KW_UI}{globals.OS_SEPARATOR}'
@@ -225,7 +226,7 @@ def addDtoToUrlVerb(verb, url, dtoClass, documentation, dtoType=v.OBJECT, where=
     if dtoClass :
         if not isinstance(dtoClass, list) :
             if not c.TYPE_DICT == dtoClass.__name__ :
-                dtoName = dtoClass.__name__
+                dtoName = getDtoDocumentationName(dtoClass)
                 if KW_REQUEST == where :
                     documentation[k.PATHS][url][verb][k.PARAMETERS].append({
                         k.NAME : v.BODY,
@@ -240,9 +241,9 @@ def addDtoToUrlVerb(verb, url, dtoClass, documentation, dtoType=v.OBJECT, where=
                         k.DESCRIPTION : v.DEFAULT_RESPONSE,
                         k.SCHEMA : getDtoSchema(dtoName, dtoType, dtoClass)
                     }
-                if not dtoClass.__name__ in documentation[k.DEFINITIONS] :
+                if not dtoName in documentation[k.DEFINITIONS] :
                     dtoClassDoc = {}
-                    documentation[k.DEFINITIONS][dtoClass.__name__] = dtoClassDoc
+                    documentation[k.DEFINITIONS][dtoName] = dtoClassDoc
                     dtoClassDoc[k.TYPE] = v.OBJECT
                     dtoClassDoc[k.PROPERTIES] = {}
                     dtoClassDoc[k.REQUIRED] = Serializer.getAttributeNameList(dtoClass)
@@ -256,6 +257,29 @@ def addDtoToUrlVerb(verb, url, dtoClass, documentation, dtoType=v.OBJECT, where=
                                 k.TYPE : attributeType,
                                 k.EXAMPLE : None
                             }
+            else :
+                dtoName = getDtoDocumentationName(dtoClass)
+                if KW_REQUEST == where :
+                    documentation[k.PATHS][url][verb][k.PARAMETERS].append({
+                        k.NAME : v.BODY,
+                        k.TYPE : v.OBJECT,
+                        k.IN : v.BODY,
+                        k.REQUIRED: True,
+                        k.DESCRIPTION : None,
+                        k.SCHEMA : getDtoSchema(dtoName, dtoType, dtoClass)
+                    })
+                if KW_RESPONSE == where :
+                    documentation[k.PATHS][url][verb][k.RESPONSES][k.DEFAULT_STATUS_CODE] = {
+                        k.DESCRIPTION : v.DEFAULT_RESPONSE,
+                        k.SCHEMA : getDtoSchema(dtoName, dtoType, dtoClass)
+                    }
+                if not dtoName in documentation[k.DEFINITIONS] :
+                    dtoClassDoc = {}
+                    documentation[k.DEFINITIONS][dtoName] = dtoClassDoc
+                    dtoClassDoc[k.TYPE] = v.OBJECT
+                    dtoClassDoc[k.PROPERTIES] = {}
+                    dtoClassDoc[k.REQUIRED] = []
+
         elif 1 == len(dtoClass) :
             if dtoClass[0] and not isinstance(dtoClass[0], list) :
                 addDtoToUrlVerb(verb, url, dtoClass[0], documentation, where=where)
@@ -285,9 +309,15 @@ def getTypeFromAttributeNameAndChildDtoClass(attributeName):
 def getRefferenceValue(name):
     return f'#/{k.DEFINITIONS}/{name}'
 
+def getDtoDocumentationName(objectClass) :
+    if Serializer.isDictionaryClass(objectClass) :
+        return JSON_OBJECT_NAME
+    else:
+        return objectClass.__name__
+
 def getDtoSchema(attributeName, attributeType, dtoClass):
     if dtoClass :
-        dtoName = dtoClass.__name__
+        dtoName = getDtoDocumentationName(dtoClass)
         if v.ARRAY == attributeType :
             return {
                 k.TYPE : v.ARRAY,
